@@ -495,7 +495,7 @@ class Model:
                 if name.startswith('_'): continue
 
                 attr = getattr(self.__class__, name)
-                if callable(attr) and not isinstance(attr, type): return
+                if callable(attr) and not isinstance(attr, type): continue
 
                 key = SEP.join([self.__class__._serie_name(), str(self._id), name])
                 name_count += 1
